@@ -11,10 +11,10 @@ pub fn build_cli() -> Command<'static> {
         .version(crate_version!())
         .color(clap_color_choice)
         .after_help(
-            r#"You just need to pipe to snazy some logs formatted as json to humm (sorry) snazzy them 💄
-eg: `kubectl logs -f controller-pod|snazy`"#
+            "You just need to pipe to snazy some logs formatted as json to humm (sorry) snazzy them 💄,eg:\n\
+            kubectl logs -f controller-pod|snazy\n\
+            Note: `fd -h` prints a short and concise overview while `fd --help` gives all details.",
         )
-
         .arg(
             Arg::new("regexp")
                 .long("regexp")
@@ -54,6 +54,11 @@ eg: `kubectl logs -f controller-pod|snazy`"#
                 .long("kail-no-prefix")
                 .help("Hide container prefix when showing the log with kail"),
         )
+        .arg(
+            Arg::new("level-symbols")
+                .long("level-symbols")
+                .help("Replace log level with pretty symbols")
+        )
         .arg(
             Arg::new("json-keys")
                 .long("json-keys")
